#
# spec file for package python-aubio
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python36 1
Name:           python-aubio
Version:        0.4.9
Release:        bp155.5.6
Summary:        A collection of tools for music analysis
License:        GPL-3.0-or-later
URL:            http://aubio.org/
Source:         http://aubio.org/pub/aubio-%{version}.tar.bz2
Source1:        http://aubio.org/pub/aubio-%{version}.tar.bz2.asc
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun):update-alternatives
%python_subpackages

%description
A python module to access the aubio library functions.

aubio is a library to label music and sounds. It listens to audio signals and attempts to detect events. For instance, when a drum is hit, at which frequency is a note, or at what tempo is a rhythmic melody.

Its features include segmenting a sound file before each of its attacks, performing pitch detection, tapping the beat and producing midi streams from live audio.

%prep
%setup -q -n aubio-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}/%{python_sitearch}
%python_clone -a %{buildroot}/%{_bindir}/aubio
%python_clone -a %{buildroot}/%{_bindir}/aubiocut

%check
# the two tests fail on 32bit due to precision issue
%pytest_arch -k 'not (test_meltohz or test_hztomel)'

%post
%{python_install_alternative aubio aubiocut}

%postun
%python_uninstall_alternative aubio

%files %{python_files}
%license COPYING
%doc README.md ChangeLog AUTHORS
%python_alternative %{_bindir}/aubio
%python_alternative %{_bindir}/aubiocut
%{python_sitearch}/*

%changelog
* Wed Apr 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Do not build for Python 3.6, due to no NumPy.
* Tue Sep  1 2020 Antonio Larrosa <alarrosa@suse.com>
- Make aubiocut a slave of aubio alternative, so the alternative
  symlink is updated in %%post (for example, to fix a dangling
  symlink to an old python version)
* Fri Mar 13 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
* Tue Feb  4 2020 Tomáš Chvátal <tchvatal@suse.com>
- Skip two tests that fail to pass on 32bit machines
* Thu Jan 30 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix the test execution
- Run fdupes during install
* Tue Feb 12 2019 bjorn.lie@gmail.com
- Update to version 0.4.9:
  * No upstream changes provided, please see
    https://git.aubio.org/?p=aubio.git;a=shortlog
- Changes from version 0.4.8:
  * src/notes: new option release_drop.
  * src/spectral: new parameters added to filterbank and mfcc.
  * python/lib: start documenting module, improve build for
    win-amd64.
  * src fixes: prevent crash when using fft sizes unsupported by
    vDSP, prevent saturation when down-mixing a multi-channel
    source (avcodec/ffmpeg).
- Changes from version 0.4.7:
  * src/io/, src/notes/, src/pitch: prevent crashes on corrupted
    files.
  * src/spectral/dct.h: add dct type II object with optimised
    versions.
  * examples/: fix jack midi output, improve messages when jack
    disabled.
  * python/: add dct support, minor bug fixes tests and demos.
  * wscript: improve support for BLAS/ATLAS.
- Run spec-cleaner, modernize spec.
* Mon Jan  1 2018 coolo@suse.com
- update to 0.4.6
  This version includes:
  * yinfast, a new version of the YIN pitch detection algorithm,
    that uses spectral convolution to compute the same results as
    the original yin, but with a cost O(N log(N)), making it much
    faster than the plain implementation (O(N^2))
  * Intel IPP optimisations (thanks to Eduard Mueller)
  * improved support for emscripten (thanks to Martin Hermant),
    which compiles the aubio library as a javascript module and
    lets you run aubio's algorithm directly from within a web-page.
  0.4.6 also comes with several bug fixes and improvements.
* Mon Apr 24 2017 alarrosa@suse.com
- Use singlespec macros
- Update to 0.4.5:
  * aubio: New python command line tool to extract information
  * Improved default parameters for onset detection, using adaptive
    spectral whitening and compression
  * Add support for libswresample
  * New options --miditap-note and --miditap-velo have been added to
    aubioonset and aubiotrack to adjust the note and velocity of the
    midi note emitted by onsets and beats.
  * Add a bunch of fixes, including improved documentation, build
    system fixes, and platform compatibility.
* Mon Feb  6 2017 alarrosa@suse.com
- Initial release
